﻿
using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Linq;
using System.Windows;

using Buddy.BehaviorTree;
using Buddy.Common;
using Buddy.CommonBot;
using Buddy.Common.Math;
using Buddy.Common.Plugins;
using Buddy.Swtor;
using Buddy.Swtor.Objects;

using WingIt.Dynamics;
using Action = Buddy.BehaviorTree.Action;



namespace Recorder
{
    public class RecorderPlugin : IPlugin
    {
        private static Vector3 lastXYZ = new Vector3();
        private static RecorderScreen recorderWindow = null;
        private static StringBuilder hotspots = new StringBuilder();
        private static StringBuilder mailboxes = new StringBuilder();
        private static StringBuilder vendors = new StringBuilder();


        public bool Equals(IPlugin other)
        {
            return other.Name == Name;
        }

        public string Author { get { return "xsol"; } }
        public Version Version { get { return new Version(1, 0); } }
        public string Name { get { return "Recorder"; } }
        public string Description { get { return "Help create profiles."; } }
        public Window DisplayWindow { get { return null; } }

        private bool PlayerMoved()
        {
            Logging.Write(LogLevel.Verbose, "[Recorder] Testing: " + string.Format("X=\"{0}\" Y=\"{1}\" Z=\"{2}\"", new object[] { BuddyTor.Me.Position.X, BuddyTor.Me.Position.Y, BuddyTor.Me.Position.Z }));
            Logging.Write(LogLevel.Verbose, "[Recorder] Distance: " + BuddyTor.Me.Position.Distance(lastXYZ).ToString());
            if (BuddyTor.Me.Position.Distance(lastXYZ) >= 4f || BuddyTor.Me.Position.Distance(lastXYZ) <= -4f)
            {
                return true;
            }
            return false;
        }

        public static void AddHotspot()
        {
            Logging.Write("[Recorder] Adding: " + string.Format("<Hotspot X=\"{0}\" Y=\"{1}\" Z=\"{2}\" />", new object[] { BuddyTor.Me.Position.X, BuddyTor.Me.Position.Y, BuddyTor.Me.Position.Z }));
            hotspots.AppendFormat(string.Format("<Hotspot Name=\"{3}\" X=\"{0}\" Y=\"{1}\" Z=\"{2}\" />", new object[] { BuddyTor.Me.Position.X, BuddyTor.Me.Position.Y, BuddyTor.Me.Position.Z, "moveToNext" }));
            recorderWindow.AddHotspot(BuddyTor.Me.Position);
            lastXYZ = BuddyTor.Me.Position;

        }

        public void OnInitialize()
        {
            if (!BotMain.IsRunning)
            {
                Logging.Write("[Recorder] You must start the bot using the CombatBot profile to use Recorder.");
            }
        }

        public void OnPulse()
        {
            if (null != recorderWindow && recorderWindow.IsRecording)
            {
                if (PlayerMoved())
                {
                    AddHotspot();
                }
            }
        }

        public void OnShutdown()
        {
            if (null != recorderWindow)
            {
                recorderWindow.Close();
                recorderWindow = null;
            }
        }

        public void OnEnabled()
        {
            if (BotMain.IsRunning)
            {
                Logging.Write("[Recorder] Enabled");
                recorderWindow = new RecorderScreen();
                recorderWindow.Show();
            }
        }

        public void OnDisabled()
        {
            Logging.Write("[Recorder] Disabled");
            if (null != recorderWindow)
            {
                recorderWindow.Close();
                recorderWindow.Dispose();
                recorderWindow = null;
            }
        }

    }
}