﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using Buddy.BehaviorTree;
using Buddy.Common;
using Buddy.CommonBot;
using Buddy.Common.Math;
using Buddy.Common.Plugins;
using Buddy.Swtor;
using Buddy.Swtor.Objects;

using WingIt.Dynamics;
using Action = Buddy.BehaviorTree.Action;


namespace Recorder
{
    public partial class RecorderScreen : Form
    {
        public RecorderScreen()
        {
            InitializeComponent();
        }

        public bool IsRecording
        {
            get
            {
                return (recordBtn.Text == "Recording") ? true : false;
            }
        }

        public void AddHotspot(Vector3 v)
        {
            hotspotLst.Items.Add(string.Format("<Hotspot Name=\"{3}\" X=\"{0}\" Y=\"{1}\" Z=\"{2}\" />", new object[] { v.X, v.Y, v.Z, "moveToNext" }));
            UpdateOutput();
        }

        private void recordBtn_Click(object sender, EventArgs e)
        {
            if (recordBtn.Text == "Record")
            {
                recordBtn.Text = "Recording";
                RecorderPlugin.AddHotspot();
            }
            else
            {
                recordBtn.Text = "Record";
            }
            UpdateOutput();
        }

        private void addBtn_Click(object sender, EventArgs e)
        {
            RecorderPlugin.AddHotspot();
        }

        private static string template = "<Profile xmlns=\"http://tempuri.org/ProfileSchema.xsd\">\r\n\t<Name>New Path</Name>\r\n\t<Vendors>{0}\r\n\t</Vendors>\r\n\t<Mailboxes>{1}\r\n\t</Mailboxes>\r\n\t<GrindAreas>\r\n\t\t<GrindArea Name=\"path\">\r\n\t\t\t\t<MinLevel>1</MinLevel>\r\n\t\t\t\t<MaxLevel>51</MaxLevel>\r\n\t\t\t\t<Hotspots>{2}\r\n\t\t\t</Hotspots>\r\n\t\t</GrindArea>\r\n\t</GrindAreas>\r\n\t<Questing><Grind GrindRef=\"path\" While=\"True\" /></Questing>\r\n</Profile>";
        public void UpdateOutput()
        {
            StringBuilder hotspots = new StringBuilder();
            StringBuilder vendors = new StringBuilder();
            StringBuilder mailboxes = new StringBuilder();

            for (int i = 0; i < hotspotLst.Items.Count; i++)
                hotspots.Append("\r\n\t\t\t\t\t" + hotspotLst.Items[i].ToString() + " ");

            for (int i = 0; i < mailboxLst.Items.Count; i++)
                mailboxes.Append("\r\n\t\t\t\t\t" + mailboxLst.Items[i].ToString() + " ");

            for (int i = 0; i < vendorLst.Items.Count; i++)
                vendors.Append("\r\n\t\t\t\t\t" + vendorLst.Items[i].ToString() + " ");

            outputTxt.Text = string.Format(template, new object[] { vendors.ToString(), mailboxes.ToString(), hotspots.ToString() });
        }

        private void addMailboxesBtn_Click(object sender, EventArgs e)
        {

            IEnumerable<TorObject> m = ObjectManager.GetObjects<Buddy.Swtor.Objects.TorObject>();
            IEnumerator<TorObject> ie = m.GetEnumerator();
            while (ie.MoveNext())
            {
                if (ie.Current.Name == "Mailbox")
                {

                    string s = string.Format(
                        "<Hotspot Name=\"{0}\" X=\"{1}\" Y=\"{2}\" Z=\"{3}\" />",
                        new object[] { 
                    ie.Current.Name,
                    ie.Current.Position.X, 
                    ie.Current.Position.Y, 
                    ie.Current.Position.Z });

                    mailboxLst.Items.Add(s);
                    Logging.Write("[Recorder] Added Mailbox: " + s);
                }
            }

            UpdateOutput();
        }

        private void addVendorBtn_Click(object sender, EventArgs e)
        {
            if (null == BuddyTor.Me.CurrentTarget) return;

            string s = string.Format(
                "<Hotspot Name=\"{0}\" X=\"{1}\" Y=\"{2}\" Z=\"{3}\" />",
                new object[] { 
                    BuddyTor.Me.CurrentTarget.Name,
                    BuddyTor.Me.CurrentTarget.Position.X, 
                    BuddyTor.Me.CurrentTarget.Position.Y, 
                    BuddyTor.Me.CurrentTarget.Position.Z });

            vendorLst.Items.Add(s);
            Logging.Write("[Recorder] Added Vendor: " + s);

            UpdateOutput();
        }

        private void outputTab_Paint(object sender, PaintEventArgs e)
        {
            UpdateOutput();
        }

    }
}
